# coding: utf-8

"""
    Mentortools Internal Sntegrations API

    Mentortools service for handling internal integrations

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
import datetime

from internal_integration_handler_connector.models.send_message_in_group_chat import SendMessageInGroupChat  # noqa: E501

class TestSendMessageInGroupChat(unittest.TestCase):
    """SendMessageInGroupChat unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> SendMessageInGroupChat:
        """Test SendMessageInGroupChat
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `SendMessageInGroupChat`
        """
        model = SendMessageInGroupChat()  # noqa: E501
        if include_optional:
            return SendMessageInGroupChat(
                portal_id = 56,
                portal_member = internal_integration_handler_connector.models.portal_member.PortalMember(
                    first_name = '', 
                    last_name = '', 
                    email = '', 
                    phone_number = '', 
                    id = 56, 
                    role_id = 56, ),
                message = '',
                chat_id = 56
            )
        else:
            return SendMessageInGroupChat(
                portal_id = 56,
                portal_member = internal_integration_handler_connector.models.portal_member.PortalMember(
                    first_name = '', 
                    last_name = '', 
                    email = '', 
                    phone_number = '', 
                    id = 56, 
                    role_id = 56, ),
                message = '',
                chat_id = 56,
        )
        """

    def testSendMessageInGroupChat(self):
        """Test SendMessageInGroupChat"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
