# coding: utf-8

"""
    Mentortools Internal Sntegrations API

    Mentortools service for handling internal integrations

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
import datetime

from internal_integration_handler_connector.models.add_new_stream_recording_to_module import AddNewStreamRecordingToModule  # noqa: E501

class TestAddNewStreamRecordingToModule(unittest.TestCase):
    """AddNewStreamRecordingToModule unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> AddNewStreamRecordingToModule:
        """Test AddNewStreamRecordingToModule
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `AddNewStreamRecordingToModule`
        """
        model = AddNewStreamRecordingToModule()  # noqa: E501
        if include_optional:
            return AddNewStreamRecordingToModule(
                portal_id = 56,
                parent_folder_id = 56,
                thumbnail_file_id = '',
                module_id = 56,
                autopublish = True,
                add_to_beginning = True,
                stream_download_url = '',
                stream_download_headers = internal_integration_handler_connector.models.stream_download_headers.Stream Download Headers()
            )
        else:
            return AddNewStreamRecordingToModule(
                portal_id = 56,
                module_id = 56,
                autopublish = True,
                stream_download_url = '',
                stream_download_headers = internal_integration_handler_connector.models.stream_download_headers.Stream Download Headers(),
        )
        """

    def testAddNewStreamRecordingToModule(self):
        """Test AddNewStreamRecordingToModule"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
