# coding: utf-8

"""
    Mentortools Internal Sntegrations API

    Mentortools service for handling internal integrations

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from internal_integration_handler_connector.api.internal_integrations_api import InternalIntegrationsApi  # noqa: E501


class TestInternalIntegrationsApi(unittest.IsolatedAsyncioTestCase):
    """InternalIntegrationsApi unit test stubs"""

    async def asyncSetUp(self) -> None:
        self.api = InternalIntegrationsApi()

    async def asyncTearDown(self) -> None:
        await self.api.api_client.close()

    async def test_internal_integrations_add_lesson_from_stream_recording(self) -> None:
        """Test case for internal_integrations_add_lesson_from_stream_recording

        Add Lesson From Stream Recording  # noqa: E501
        """
        pass

    async def test_internal_integrations_add_tags_to_portal_member(self) -> None:
        """Test case for internal_integrations_add_tags_to_portal_member

        Add Tags To Portal Member  # noqa: E501
        """
        pass

    async def test_internal_integrations_add_user_to_group_chat(self) -> None:
        """Test case for internal_integrations_add_user_to_group_chat

        Add User To Group Chat  # noqa: E501
        """
        pass

    async def test_internal_integrations_create_order(self) -> None:
        """Test case for internal_integrations_create_order

        Create Order  # noqa: E501
        """
        pass

    async def test_internal_integrations_remove_tags_from_portal_member(self) -> None:
        """Test case for internal_integrations_remove_tags_from_portal_member

        Remove Tags From Portal Member  # noqa: E501
        """
        pass

    async def test_internal_integrations_remove_user_from_group_chat(self) -> None:
        """Test case for internal_integrations_remove_user_from_group_chat

        Remove User From Group Chat  # noqa: E501
        """
        pass

    async def test_internal_integrations_send_chat_message_to_group_chat(self) -> None:
        """Test case for internal_integrations_send_chat_message_to_group_chat

        Send Chat Message To Group Chat  # noqa: E501
        """
        pass

    async def test_internal_integrations_send_personal_chat_message(self) -> None:
        """Test case for internal_integrations_send_personal_chat_message

        Send Personal Chat Message  # noqa: E501
        """
        pass

    async def test_internal_integrations_validate_message_template(self) -> None:
        """Test case for internal_integrations_validate_message_template

        Validate Message Template  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
